@@ -29,7 +29,6 @@ import (
 	"github.com/tektoncd/triggers/pkg/apis/triggers/v1alpha1"
 	"github.com/tektoncd/triggers/pkg/system"
 	"github.com/tektoncd/triggers/test"
-	bldr "github.com/tektoncd/triggers/test/builder"
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/resource"
@@ -40,6 +39,8 @@ import (
 	k8stest "k8s.io/client-go/testing"
 	"knative.dev/pkg/apis"
 	duckv1 "knative.dev/pkg/apis/duck/v1"
+	duckv1alpha1 "knative.dev/pkg/apis/duck/v1alpha1"
+	duckv1beta1 "knative.dev/pkg/apis/duck/v1beta1"
 	fakekubeclient "knative.dev/pkg/client/injection/kube/client/fake"
 	cminformer "knative.dev/pkg/configmap/informer"
 	"knative.dev/pkg/ptr"
@@ -98,6 +99,11 @@ var (
 	replicas int32 = 1
 )
 
+// compareCondition compares two conditions based on their Type field.
+func compareCondition(x, y apis.Condition) bool {
+	return x.Type < y.Type
+}
+
 // getEventListenerTestAssets returns TestAssets that have been seeded with the
 // given test.Resources r where r represents the state of the system
 func getEventListenerTestAssets(t *testing.T, r test.Resources, c *Config) (test.Assets, context.CancelFunc) {
@@ -163,11 +169,15 @@ func makeConfig(ops ...func(d *Config)) *Config {
 // It generates a base EventListener that can then be modified by the passed in op function
 // If no ops are specified, it generates a base EventListener with no triggers and no Status
 func makeEL(ops ...func(el *v1alpha1.EventListener)) *v1alpha1.EventListener {
-	e := bldr.EventListener(eventListenerName, namespace,
-		bldr.EventListenerSpec(
-			bldr.EventListenerServiceAccount("sa"),
-		),
-	)
+	e := &v1alpha1.EventListener{
+		ObjectMeta: metav1.ObjectMeta{
+			Name:      eventListenerName,
+			Namespace: namespace,
+		},
+		Spec: v1alpha1.EventListenerSpec{
+			ServiceAccountName: "sa",
+		},
+	}
 	for _, op := range ops {
 		op(e)
 	}
@@ -205,6 +215,9 @@ func makeDeployment(ops ...func(d *appsv1.Deployment)) *appsv1.Deployment {
 						Ports: []corev1.ContainerPort{{
 							ContainerPort: int32(eventListenerContainerPort),
 							Protocol:      corev1.ProtocolTCP,
+						}, {
+							ContainerPort: int32(9000),
+							Protocol:      corev1.ProtocolTCP,
 						}},
 						LivenessProbe: &corev1.Probe{
 							Handler: corev1.Handler{
@@ -242,15 +255,21 @@ func makeDeployment(ops ...func(d *appsv1.Deployment)) *appsv1.Deployment {
 							MountPath: "/etc/config-logging",
 						}},
 						Env: []corev1.EnvVar{{
-							Name:  "TEKTON_INSTALL_NAMESPACE",
-							Value: "tekton-pipelines",
-						}, {
 							Name: "SYSTEM_NAMESPACE",
 							ValueFrom: &corev1.EnvVarSource{
 								FieldRef: &corev1.ObjectFieldSelector{
 									FieldPath: "metadata.namespace",
 								},
 							},
+						}, {
+							Name:  "CONFIG_OBSERVABILITY_NAME",
+							Value: "config-observability",
+						}, {
+							Name:  "METRICS_DOMAIN",
+							Value: "tekton.dev/triggers",
+						}, {
+							Name:  "METRICS_PROMETHEUS_PORT",
+							Value: "9000",
 						}},
 					}},
 					Volumes: []corev1.Volume{{
@@ -291,6 +310,9 @@ var withTLSConfig = func(d *appsv1.Deployment) {
 		Ports: []corev1.ContainerPort{{
 			ContainerPort: int32(eventListenerContainerPort),
 			Protocol:      corev1.ProtocolTCP,
+		}, {
+			ContainerPort: int32(9000),
+			Protocol:      corev1.ProtocolTCP,
 		}},
 		LivenessProbe: &corev1.Probe{
 			Handler: corev1.Handler{
@@ -330,9 +352,6 @@ var withTLSConfig = func(d *appsv1.Deployment) {
 			ReadOnly:  true,
 		}},
 		Env: []corev1.EnvVar{{
-			Name:  "TEKTON_INSTALL_NAMESPACE",
-			Value: "tekton-pipelines",
-		}, {
 			Name: "TLS_CERT",
 			ValueFrom: &corev1.EnvVarSource{
 				SecretKeyRef: &corev1.SecretKeySelector{
@@ -359,6 +378,15 @@ var withTLSConfig = func(d *appsv1.Deployment) {
 					FieldPath: "metadata.namespace",
 				},
 			},
+		}, {
+			Name:  "CONFIG_OBSERVABILITY_NAME",
+			Value: "config-observability",
+		}, {
+			Name:  "METRICS_DOMAIN",
+			Value: "tekton.dev/triggers",
+		}, {
+			Name:  "METRICS_PROMETHEUS_PORT",
+			Value: "9000",
 		}},
 	}}
 	d.Spec.Template.Spec.Volumes = []corev1.Volume{{
@@ -424,11 +452,17 @@ func makeWithPod(ops ...func(d *duckv1.WithPod)) *duckv1.WithPod {
 							ReadOnly:  true,
 						}},
 						Env: []corev1.EnvVar{{
-							Name:  "TEKTON_INSTALL_NAMESPACE",
-							Value: "tekton-pipelines",
-						}, {
 							Name:  "SYSTEM_NAMESPACE",
 							Value: "test-pipelines",
+						}, {
+							Name:  "CONFIG_OBSERVABILITY_NAME",
+							Value: "config-observability",
+						}, {
+							Name:  "METRICS_DOMAIN",
+							Value: "tekton.dev/triggers",
+						}, {
+							Name:  "METRICS_PROMETHEUS_PORT",
+							Value: "9000",
 						}},
 					}},
 					Volumes: []corev1.Volume{{
@@ -490,50 +524,75 @@ func logConfig(ns string) *corev1.ConfigMap {
 	return lc
 }
 
-var withTLSPort = bldr.EventListenerStatus(
-	bldr.EventListenerAddress(listenerHostname(generatedResourceName, namespace, 8443)),
-)
+func withTLSPort(el *v1alpha1.EventListener) {
+	el.Status.Address = &duckv1alpha1.Addressable{
+		Addressable: duckv1beta1.Addressable{
+			URL: &apis.URL{
+				Scheme: "http",
+				Host:   listenerHostname(generatedResourceName, namespace, 8443),
+			},
+		},
+	}
+}
 
-var withKnativeStatus = bldr.EventListenerStatus(
-	bldr.EventListenerCondition(
-		v1alpha1.ServiceExists,
-		corev1.ConditionFalse,
-		"", "",
-	),
-	bldr.EventListenerCondition(
-		v1alpha1.DeploymentExists,
-		corev1.ConditionFalse,
-		"", "",
-	),
-)
+func withKnativeStatus(el *v1alpha1.EventListener) {
+	el.Status.Status = duckv1.Status{
+		Conditions: []apis.Condition{{
+			Type:   v1alpha1.ServiceExists,
+			Status: corev1.ConditionFalse,
+		}, {
+			Type:   v1alpha1.DeploymentExists,
+			Status: corev1.ConditionFalse,
+		}, {
+			Type:   apis.ConditionReady,
+			Status: corev1.ConditionFalse,
+		}},
+	}
+}
 
-var withStatus = bldr.EventListenerStatus(
-	bldr.EventListenerConfig(generatedResourceName),
-	bldr.EventListenerAddress(listenerHostname(generatedResourceName, namespace, DefaultPort)),
-	bldr.EventListenerCondition(
-		v1alpha1.ServiceExists,
-		corev1.ConditionTrue,
-		"Service exists", "",
-	),
-	bldr.EventListenerCondition(
-		v1alpha1.DeploymentExists,
-		corev1.ConditionTrue,
-		"Deployment exists", "",
-	),
-	bldr.EventListenerCondition(
-		apis.ConditionType(appsv1.DeploymentAvailable),
-		corev1.ConditionTrue,
-		"Deployment has minimum availability",
-		"MinimumReplicasAvailable",
-	),
-	bldr.EventListenerCondition(
-		apis.ConditionType(appsv1.DeploymentProgressing),
-		corev1.ConditionTrue,
-		fmt.Sprintf("ReplicaSet \"%s\" has successfully progressed.", eventListenerName),
-		"NewReplicaSetAvailable",
-	),
-)
+func withStatus(el *v1alpha1.EventListener) {
+	el.Status = v1alpha1.EventListenerStatus{
+		Status: duckv1.Status{
+			Conditions: []apis.Condition{{
+				Type:    apis.ConditionType(appsv1.DeploymentAvailable),
+				Status:  corev1.ConditionTrue,
+				Message: "Deployment has minimum availability",
+				Reason:  "MinimumReplicasAvailable",
+			}, {
+				Type:    v1alpha1.DeploymentExists,
+				Status:  corev1.ConditionTrue,
+				Message: "Deployment exists",
+			}, {
+				Type:    apis.ConditionType(appsv1.DeploymentProgressing),
+				Status:  corev1.ConditionTrue,
+				Message: fmt.Sprintf("ReplicaSet \"%s\" has successfully progressed.", eventListenerName),
+				Reason:  "NewReplicaSetAvailable",
+			}, {
+				Type:    apis.ConditionReady,
+				Status:  corev1.ConditionTrue,
+				Message: "EventListener is ready",
+			}, {
+				Type:    v1alpha1.ServiceExists,
+				Status:  corev1.ConditionTrue,
+				Message: "Service exists",
+			}},
+		},
+		AddressStatus: duckv1alpha1.AddressStatus{
+			Address: &duckv1alpha1.Addressable{
+				Addressable: duckv1beta1.Addressable{
+					URL: &apis.URL{
+						Scheme: "http",
+						Host:   listenerHostname(generatedResourceName, namespace, DefaultPort),
+					},
+				},
+			},
+		},
+		Configuration: v1alpha1.EventListenerConfig{
+			GeneratedResourceName: generatedResourceName,
+		},
+	}
 
+}
 func withAddedLabels(el *v1alpha1.EventListener) {
 	el.Labels = updateLabel
 }
@@ -559,7 +618,11 @@ func withDeletionTimestamp(el *v1alpha1.EventListener) {
 }
 
 func TestReconcile(t *testing.T) {
-	err := os.Setenv("SYSTEM_NAMESPACE", "tekton-pipelines")
+	err := os.Setenv("METRICS_PROMETHEUS_PORT", "9000")
+	if err != nil {
+		t.Fatal(err)
+	}
+	err = os.Setenv("SYSTEM_NAMESPACE", "tekton-pipelines")
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -611,7 +674,9 @@ func TestReconcile(t *testing.T) {
 	})
 
 	elWithReplicas := makeEL(withStatus, func(el *v1alpha1.EventListener) {
-		el.Spec.Replicas = ptr.Int32(2)
+		el.Spec.Resources.KubernetesResource = &v1alpha1.KubernetesResource{
+			Replicas: ptr.Int32(2),
+		}
 	})
 
 	elWithDeploymentReplicaFailure := makeEL(withStatus, func(el *v1alpha1.EventListener) {
@@ -804,9 +869,16 @@ func TestReconcile(t *testing.T) {
 		}
 	})
 
-	elWithPortSet := makeEL(withStatus, bldr.EventListenerStatus(
-		bldr.EventListenerAddress(listenerHostname(generatedResourceName, namespace, customPort)),
-	))
+	elWithPortSet := makeEL(withStatus, func(el *v1alpha1.EventListener) {
+		el.Status.Address = &duckv1alpha1.Addressable{
+			Addressable: duckv1beta1.Addressable{
+				URL: &apis.URL{
+					Scheme: "http",
+					Host:   listenerHostname(generatedResourceName, namespace, customPort),
+				},
+			},
+		}
+	})
 
 	elDeployment := makeDeployment()
 	elDeploymentWithLabels := makeDeployment(func(d *appsv1.Deployment) {
@@ -896,9 +968,6 @@ func TestReconcile(t *testing.T) {
 	})
 	envForCustomResource := makeWithPod(func(data *duckv1.WithPod) {
 		data.Spec.Template.Spec.Containers[0].Env = []corev1.EnvVar{{
-			Name:  "TEKTON_INSTALL_NAMESPACE",
-			Value: "tekton-pipelines",
-		}, {
 			Name: "key",
 			ValueFrom: &corev1.EnvVarSource{
 				SecretKeyRef: &corev1.SecretKeySelector{
@@ -909,6 +978,15 @@ func TestReconcile(t *testing.T) {
 		}, {
 			Name:  "SYSTEM_NAMESPACE",
 			Value: "test-pipelines",
+		}, {
+			Name:  "CONFIG_OBSERVABILITY_NAME",
+			Value: "config-observability",
+		}, {
+			Name:  "METRICS_DOMAIN",
+			Value: "tekton.dev/triggers",
+		}, {
+			Name:  "METRICS_PROMETHEUS_PORT",
+			Value: "9000",
 		}}
 	})
 
@@ -943,6 +1021,8 @@ func TestReconcile(t *testing.T) {
 
 	loggingConfigMap := defaultLoggingConfigMap()
 	loggingConfigMap.ObjectMeta.Namespace = namespace
+	observabilityConfigMap := defaultObservabilityConfigMap()
+	observabilityConfigMap.ObjectMeta.Namespace = namespace
 	reconcilerLoggingConfigMap := defaultLoggingConfigMap()
 	reconcilerLoggingConfigMap.ObjectMeta.Namespace = reconcilerNamespace
 
@@ -964,7 +1044,7 @@ func TestReconcile(t *testing.T) {
 			EventListeners: []*v1alpha1.EventListener{makeEL(withStatus)},
 			Deployments:    []*appsv1.Deployment{makeDeployment()},
 			Services:       []*corev1.Service{makeService()},
-			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
 		},
 	}, {
 		name: "eventlistener with additional label",
@@ -984,7 +1064,7 @@ func TestReconcile(t *testing.T) {
 			EventListeners: []*v1alpha1.EventListener{makeEL(withStatus, withAddedLabels)},
 			Deployments:    []*appsv1.Deployment{elDeploymentWithLabels},
 			Services:       []*corev1.Service{elServiceWithLabels},
-			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
 		},
 	}, {
 		name: "eventlistener with additional annotation",
@@ -1002,7 +1082,7 @@ func TestReconcile(t *testing.T) {
 			EventListeners: []*v1alpha1.EventListener{makeEL(withStatus, withAddedAnnotations)},
 			Deployments:    []*appsv1.Deployment{elDeploymentWithAnnotations},
 			Services:       []*corev1.Service{elServiceWithAnnotation},
-			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
 		},
 	}, {
 		name: "eventlistener with updated service account",
@@ -1018,7 +1098,7 @@ func TestReconcile(t *testing.T) {
 			EventListeners: []*v1alpha1.EventListener{elWithUpdatedSA},
 			Deployments:    []*appsv1.Deployment{elDeploymentWithUpdatedSA},
 			Services:       []*corev1.Service{elService},
-			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
 		},
 	}, {
 		name: "eventlistener with added tolerations",
@@ -1034,7 +1114,7 @@ func TestReconcile(t *testing.T) {
 			EventListeners: []*v1alpha1.EventListener{elWithTolerations},
 			Deployments:    []*appsv1.Deployment{elDeploymentWithTolerations},
 			Services:       []*corev1.Service{elService},
-			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
 		},
 	}, {
 		name: "eventlistener with added NodeSelector",
@@ -1050,7 +1130,7 @@ func TestReconcile(t *testing.T) {
 			EventListeners: []*v1alpha1.EventListener{elWithNodeSelector},
 			Deployments:    []*appsv1.Deployment{elDeploymentWithNodeSelector},
 			Services:       []*corev1.Service{elService},
-			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
 		},
 	}, {
 		name: "eventlistener with NodePort service",
@@ -1066,7 +1146,7 @@ func TestReconcile(t *testing.T) {
 			EventListeners: []*v1alpha1.EventListener{elWithNodePortServiceType},
 			Deployments:    []*appsv1.Deployment{elDeployment},
 			Services:       []*corev1.Service{elServiceTypeNodePort},
-			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
 		},
 	}, {
 		// Check that if a user manually updates the labels for a service, we revert the change.
@@ -1083,7 +1163,7 @@ func TestReconcile(t *testing.T) {
 			EventListeners: []*v1alpha1.EventListener{elWithStatus},
 			Services:       []*corev1.Service{elService}, // We expect the service to drop the user added labels
 			Deployments:    []*appsv1.Deployment{elDeployment},
-			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
 		},
 	}, {
 		// Check that if a user manually updates the annotations for a service, we do not revert the change.
@@ -1100,7 +1180,7 @@ func TestReconcile(t *testing.T) {
 			EventListeners: []*v1alpha1.EventListener{elWithStatus},
 			Services:       []*corev1.Service{elServiceWithAnnotation},
 			Deployments:    []*appsv1.Deployment{elDeployment},
-			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
 		},
 	}, {
 		// Checks that EL reconciler does not overwrite NodePort set by k8s (see #167)
@@ -1117,7 +1197,7 @@ func TestReconcile(t *testing.T) {
 			EventListeners: []*v1alpha1.EventListener{elWithNodePortServiceType},
 			Deployments:    []*appsv1.Deployment{elDeployment},
 			Services:       []*corev1.Service{elServiceWithUpdatedNodePort},
-			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
 		},
 	}, {
 		name: "eventlistener with labels applied to deployment",
@@ -1133,7 +1213,7 @@ func TestReconcile(t *testing.T) {
 			EventListeners: []*v1alpha1.EventListener{elWithStatus},
 			Deployments:    []*appsv1.Deployment{elDeployment},
 			Services:       []*corev1.Service{elService},
-			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
 		},
 	}, {
 		// Check that if a user manually updates the annotations for a deployment, we do not revert the change.
@@ -1150,7 +1230,7 @@ func TestReconcile(t *testing.T) {
 			EventListeners: []*v1alpha1.EventListener{elWithStatus},
 			Deployments:    []*appsv1.Deployment{elDeploymentWithAnnotations},
 			Services:       []*corev1.Service{elService},
-			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
 		},
 	}, {
 		// Updating replicas on deployment itself is success because no replicas provided as part of eventlistener spec
@@ -1167,7 +1247,7 @@ func TestReconcile(t *testing.T) {
 			EventListeners: []*v1alpha1.EventListener{elWithStatus},
 			Deployments:    []*appsv1.Deployment{deploymentWithUpdatedReplicas},
 			Services:       []*corev1.Service{elService},
-			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
 		},
 	}, {
 		name: "eventlistener with failed update to deployment replicas",
@@ -1183,7 +1263,7 @@ func TestReconcile(t *testing.T) {
 			EventListeners: []*v1alpha1.EventListener{elWithStatus},
 			Deployments:    []*appsv1.Deployment{elDeployment},
 			Services:       []*corev1.Service{elService},
-			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
 		},
 	}, {
 		name: "eventlistener with updated config volumes",
@@ -1198,7 +1278,7 @@ func TestReconcile(t *testing.T) {
 			EventListeners: []*v1alpha1.EventListener{makeEL(withStatus)},
 			Deployments:    []*appsv1.Deployment{elDeployment},
 			Services:       []*corev1.Service{elService},
-			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
 		},
 	}, {
 		// Checks that we do not overwrite replicas changed on the deployment itself when replicas provided as part of eventlistener spec
@@ -1215,7 +1295,7 @@ func TestReconcile(t *testing.T) {
 			EventListeners: []*v1alpha1.EventListener{elWithReplicas},
 			Deployments:    []*appsv1.Deployment{deploymentWithUpdatedReplicasNotConsidered},
 			Services:       []*corev1.Service{elService},
-			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
 		},
 	}, {
 		name: "eventlistener with kubernetes resource",
@@ -1223,12 +1303,12 @@ func TestReconcile(t *testing.T) {
 		startResources: test.Resources{
 			Namespaces:     []*corev1.Namespace{namespaceResource},
 			EventListeners: []*v1alpha1.EventListener{elWithKubernetesResource},
-			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
 		},
 		endResources: test.Resources{
 			Namespaces:     []*corev1.Namespace{namespaceResource},
 			EventListeners: []*v1alpha1.EventListener{elWithKubernetesResource},
-			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
 			Deployments:    []*appsv1.Deployment{deploymentForKubernetesResource},
 			Services:       []*corev1.Service{elServiceTypeNodePort},
 		},
@@ -1238,12 +1318,12 @@ func TestReconcile(t *testing.T) {
 		startResources: test.Resources{
 			Namespaces:     []*corev1.Namespace{namespaceResource},
 			EventListeners: []*v1alpha1.EventListener{elWithKubernetesResourceForObjectMeta},
-			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
 		},
 		endResources: test.Resources{
 			Namespaces:     []*corev1.Namespace{namespaceResource},
 			EventListeners: []*v1alpha1.EventListener{elWithKubernetesResourceForObjectMeta},
-			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
 			Deployments:    []*appsv1.Deployment{deploymentForKubernetesResourceObjectMeta},
 			Services:       []*corev1.Service{elService},
 		},
@@ -1253,12 +1333,12 @@ func TestReconcile(t *testing.T) {
 		startResources: test.Resources{
 			Namespaces:     []*corev1.Namespace{namespaceResource},
 			EventListeners: []*v1alpha1.EventListener{elWithTLSConnection},
-			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
 		},
 		endResources: test.Resources{
 			Namespaces:     []*corev1.Namespace{namespaceResource},
 			EventListeners: []*v1alpha1.EventListener{elWithTLSConnection},
-			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
 			Deployments:    []*appsv1.Deployment{deploymentWithTLSConnection},
 			Services:       []*corev1.Service{elServiceWithTLSConnection},
 		},
@@ -1269,14 +1349,14 @@ func TestReconcile(t *testing.T) {
 			Namespaces:     []*corev1.Namespace{namespaceResource},
 			EventListeners: []*v1alpha1.EventListener{elWithStatus},
 			Deployments:    []*appsv1.Deployment{deploymentMissingSecurityContext},
-			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
 		},
 		endResources: test.Resources{
 			Namespaces:     []*corev1.Namespace{namespaceResource},
 			EventListeners: []*v1alpha1.EventListener{elWithStatus},
 			Deployments:    []*appsv1.Deployment{elDeployment},
 			Services:       []*corev1.Service{elService},
-			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
 		},
 	}, {
 		name:   "eventlistener with SetSecurityContext false",
@@ -1286,14 +1366,14 @@ func TestReconcile(t *testing.T) {
 			Namespaces:     []*corev1.Namespace{namespaceResource},
 			EventListeners: []*v1alpha1.EventListener{elWithStatus},
 			Deployments:    []*appsv1.Deployment{deploymentMissingSecurityContext},
-			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
 		},
 		endResources: test.Resources{
 			Namespaces:     []*corev1.Namespace{namespaceResource},
 			EventListeners: []*v1alpha1.EventListener{elWithStatus},
 			Deployments:    []*appsv1.Deployment{deploymentMissingSecurityContext},
 			Services:       []*corev1.Service{elService},
-			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
 		},
 	}, {
 		name:   "eventlistener with port set in config",
@@ -1303,27 +1383,27 @@ func TestReconcile(t *testing.T) {
 			Namespaces:     []*corev1.Namespace{namespaceResource},
 			EventListeners: []*v1alpha1.EventListener{elWithStatus},
 			Deployments:    []*appsv1.Deployment{elDeployment},
-			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
 		},
 		endResources: test.Resources{
 			Namespaces:     []*corev1.Namespace{namespaceResource},
 			EventListeners: []*v1alpha1.EventListener{elWithPortSet},
 			Deployments:    []*appsv1.Deployment{elDeployment},
 			Services:       []*corev1.Service{elServiceWithPortSet},
-			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
 		},
 	}, {
-		name: "eventlistener with added env for custome resource",
+		name: "eventlistener with added env for custom resource",
 		key:  reconcileKey,
 		startResources: test.Resources{
 			Namespaces:     []*corev1.Namespace{namespaceResource},
 			EventListeners: []*v1alpha1.EventListener{elWithCustomResourceForEnv},
-			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
 		},
 		endResources: test.Resources{
 			Namespaces:     []*corev1.Namespace{namespaceResource},
 			EventListeners: []*v1alpha1.EventListener{elWithCustomResourceForEnv},
-			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
 			WithPod:        []*duckv1.WithPod{envForCustomResource},
 		},
 	}, {
@@ -1332,13 +1412,13 @@ func TestReconcile(t *testing.T) {
 		startResources: test.Resources{
 			Namespaces:     []*corev1.Namespace{namespaceResource},
 			EventListeners: []*v1alpha1.EventListener{elWithCustomResourceForNodeSelector},
-			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
 			WithPod:        []*duckv1.WithPod{nodeSelectorForCustomResource},
 		},
 		endResources: test.Resources{
 			Namespaces:     []*corev1.Namespace{namespaceResource},
 			EventListeners: []*v1alpha1.EventListener{elWithCustomResourceForNodeSelector},
-			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
 			WithPod:        []*duckv1.WithPod{nodeSelectorForCustomResource},
 		},
 	}, {
@@ -1347,12 +1427,12 @@ func TestReconcile(t *testing.T) {
 		startResources: test.Resources{
 			Namespaces:     []*corev1.Namespace{namespaceResource},
 			EventListeners: []*v1alpha1.EventListener{elWithCustomResourceForArgs},
-			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
 		},
 		endResources: test.Resources{
 			Namespaces:     []*corev1.Namespace{namespaceResource},
 			EventListeners: []*v1alpha1.EventListener{elWithCustomResourceForArgs},
-			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
 			WithPod:        []*duckv1.WithPod{argsForCustomResource},
 		},
 	}, {
@@ -1361,12 +1441,12 @@ func TestReconcile(t *testing.T) {
 		startResources: test.Resources{
 			Namespaces:     []*corev1.Namespace{namespaceResource},
 			EventListeners: []*v1alpha1.EventListener{elWithCustomResourceForImage},
-			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
 		},
 		endResources: test.Resources{
 			Namespaces:     []*corev1.Namespace{namespaceResource},
 			EventListeners: []*v1alpha1.EventListener{elWithCustomResourceForImage},
-			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
 			WithPod:        []*duckv1.WithPod{imageForCustomResource},
 		},
 	}, {
@@ -1375,14 +1455,31 @@ func TestReconcile(t *testing.T) {
 		startResources: test.Resources{
 			Namespaces:     []*corev1.Namespace{namespaceResource},
 			EventListeners: []*v1alpha1.EventListener{elWithCustomResourceForAnnotation},
-			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
 		},
 		endResources: test.Resources{
 			Namespaces:     []*corev1.Namespace{namespaceResource},
 			EventListeners: []*v1alpha1.EventListener{elWithCustomResourceForAnnotation},
-			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
 			WithPod:        []*duckv1.WithPod{annotationForCustomResource},
 		},
+	}, {
+		name: "eventlistener with cleanup test to ensure no k8s resource exist after upgrading to customresource",
+		key:  reconcileKey,
+		startResources: test.Resources{
+			Namespaces:     []*corev1.Namespace{namespaceResource},
+			EventListeners: []*v1alpha1.EventListener{elWithCustomResourceForNodeSelector},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
+			WithPod:        []*duckv1.WithPod{nodeSelectorForCustomResource},
+			Deployments:    []*appsv1.Deployment{makeDeployment()},
+			Services:       []*corev1.Service{makeService()},
+		},
+		endResources: test.Resources{
+			Namespaces:     []*corev1.Namespace{namespaceResource},
+			EventListeners: []*v1alpha1.EventListener{elWithCustomResourceForNodeSelector},
+			ConfigMaps:     []*corev1.ConfigMap{loggingConfigMap, observabilityConfigMap},
+			WithPod:        []*duckv1.WithPod{nodeSelectorForCustomResource},
+		},
 	},
 	}
 	for _, tt := range tests {
@@ -1404,7 +1501,7 @@ func TestReconcile(t *testing.T) {
 			if diff := cmp.Diff(tt.endResources, *actualEndResources, cmpopts.IgnoreTypes(
 				apis.Condition{}.LastTransitionTime.Inner.Time,
 				metav1.ObjectMeta{}.Finalizers,
-			)); diff != "" {
+			), cmpopts.SortSlices(compareCondition)); diff != "" {
 				t.Errorf("eventlistener.Reconcile() equality mismatch. Diff request body: -want +got: %s", diff)
 			}
 		})
@@ -1478,9 +1575,6 @@ func TestReconcile_InvalidForCustomResource(t *testing.T) {
 		data.Spec.Template.Spec.Containers[0].Env = []corev1.EnvVar{{
 			Name:  "SYSTEM_NAMESPACE",
 			Value: "test-pipelines",
-		}, {
-			Name:  "TEKTON_INSTALL_NAMESPACE",
-			Value: "tekton-pipelines",
 		}, {
 			Name: "key1",
 			ValueFrom: &corev1.EnvVarSource{
@@ -1573,7 +1667,7 @@ func TestReconcile_InvalidForCustomResource(t *testing.T) {
 			if diff := cmp.Diff(tt.endResources, *actualEndResources, cmpopts.IgnoreTypes(
 				apis.Condition{}.LastTransitionTime.Inner.Time,
 				metav1.ObjectMeta{}.Finalizers,
-			)); diff == "" {
+			), cmpopts.SortSlices(compareCondition)); diff == "" {
 				t.Errorf("eventlistener.Reconcile() equality mismatch. Diff request body: -want +got: %s", diff)
 			}
 		})
@@ -1808,7 +1902,12 @@ func Test_generateObjectMeta(t *testing.T) {
 		expectedObjectMeta metav1.ObjectMeta
 	}{{
 		name: "Empty EventListener",
-		el:   bldr.EventListener(eventListenerName, ""),
+		el: &v1alpha1.EventListener{
+			ObjectMeta: metav1.ObjectMeta{
+				Name:      eventListenerName,
+				Namespace: "",
+			},
+		},
 		expectedObjectMeta: metav1.ObjectMeta{
 			Namespace: "",
 			Name:      "",
@@ -1824,11 +1923,18 @@ func Test_generateObjectMeta(t *testing.T) {
 		},
 	}, {
 		name: "EventListener with Configuration",
-		el: bldr.EventListener(eventListenerName, "",
-			bldr.EventListenerStatus(
-				bldr.EventListenerConfig("generatedName"),
-			),
-		),
+		el: &v1alpha1.EventListener{
+			ObjectMeta: metav1.ObjectMeta{
+				Name:      eventListenerName,
+				Namespace: "",
+			},
+			Status: v1alpha1.EventListenerStatus{
+				Configuration: v1alpha1.EventListenerConfig{
+					GeneratedResourceName: "generatedName",
+				},
+			},
+		},
+
 		expectedObjectMeta: metav1.ObjectMeta{
 			Namespace: "",
 			Name:      "generatedName",
@@ -1844,11 +1950,15 @@ func Test_generateObjectMeta(t *testing.T) {
 		},
 	}, {
 		name: "EventListener with Labels",
-		el: bldr.EventListener(eventListenerName, "",
-			bldr.EventListenerMeta(
-				bldr.Label("k", "v"),
-			),
-		),
+		el: &v1alpha1.EventListener{
+			ObjectMeta: metav1.ObjectMeta{
+				Name:      eventListenerName,
+				Namespace: "",
+				Labels: map[string]string{
+					"k": "v",
+				},
+			},
+		},
 		expectedObjectMeta: metav1.ObjectMeta{
 			Namespace: "",
 			Name:      "",
@@ -1864,11 +1974,15 @@ func Test_generateObjectMeta(t *testing.T) {
 		},
 	}, {
 		name: "EventListener with Annotation",
-		el: bldr.EventListener(eventListenerName, "",
-			bldr.EventListenerMeta(
-				bldr.Annotation("k", "v"),
-			),
-		),
+		el: &v1alpha1.EventListener{
+			ObjectMeta: metav1.ObjectMeta{
+				Name:      eventListenerName,
+				Namespace: "",
+				Annotations: map[string]string{
+					"k": "v",
+				},
+			},
+		},
 		expectedObjectMeta: metav1.ObjectMeta{
 			Namespace: "",
 			Name:      "",
